
class CustomSerializerMixin:
    default_serializer_class = None  # Your default serializer
    serializer_classes = {
    }

    def get_serializer_class(self):
        return self.serializer_classes.get(self.action, self.default_serializer_class)




# allows from rest_framework.decorators import permission_classes to be used on class based views
class PermissionDecoratorMixin:
    def get_permissions(self):
        # Check if the action has custom permission classes
        action = getattr(self, self.action, None)
        if action and hasattr(action, "permission_classes"):
            permission_classes = action.permission_classes
        else:
            permission_classes = self.permission_classes

        return [permission() for permission in permission_classes]



class PermissionActionMixin:
    default_permission_classes = None
    action_permission_classes = {}
    extend_base_permissions = True      # False overrides the base permissions

    def get_permissions(self):
        # Start with the global permission classes defined on the view
        base_permission_classes = getattr(self, 'permission_classes', [])
        
        # Get action-specific permission classes
        action_permissions = self.action_permission_classes.get(
            self.action, 
            self.default_permission_classes or []
        )
        
        # Handle permission combinations and convert to list if needed
        if action_permissions and not isinstance(action_permissions, (list, tuple)):
            action_permissions = [action_permissions]
        else:
            action_permissions = action_permissions or []
            
        # If extend_base_permissions is False and we have action-specific permissions,
        # use ONLY the action permissions
        if not self.extend_base_permissions and action_permissions:
            final_permissions = action_permissions
        else:
            # Otherwise, combine base permissions with action-specific ones
            final_permissions = base_permission_classes + action_permissions
        
        return [permission() for permission in final_permissions]




# setup.py
from setuptools import setup, find_packages

setup(
    name='aih_django',
    version='0.0.6',
    packages=find_packages(),
    description='A collection of Django utilities',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Joseph',
    author_email='joseph@aiheroes.io',
    url='https://github.com/AI-Heroes/aih-django/tree/0.0.1',
    install_requires=[
        'Django>=3.2',  # Specify the Django version compatibility
    ],
    classifiers=[
        'Framework :: Django',
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)
